@@ -1,6 +1,5 @@
 /* Program version */
-/* not for the inetutils version */
-#define VERSION "4.7.24"
+#define VERSION "4.7.27"
 
 /* Configurable features */
 
@@ -15,6 +14,7 @@
 #define CONFIG_FILE "/etc/whois.conf"
 */
 
+
 /* autoconf in cpp macros */
 #ifdef linux
 # define ENABLE_NLS
@@ -34,16 +34,18 @@
 # define HAVE_GETADDRINFO
 #endif
 
+#if defined __APPLE__ && defined __MACH__
+# define HAVE_GETADDRINFO
+#endif
+
 #if defined __GLIBC__
 # define HAVE_GETOPT_LONG
 # if __GLIBC__ >= 2 && __GLIBC_MINOR__ >= 1
 #  define HAVE_GETADDRINFO
 # endif
-#endif
-
-/* Linux, Solaris 5, FreeBSD 5.x. What else? */
-#if defined _POSIX_VERSION && _POSIX_VERSION >= 200112L
-# define HAVE_WORDEXP
+# if __GLIBC__ >= 2 && __GLIBC_MINOR__ >= 7
+#  define HAVE_SHA_CRYPT
+# endif
 #endif
 
 #if defined _POSIX2_VERSION
@@ -51,7 +53,6 @@
 #endif
 
 
-/* system features */
 #ifdef ENABLE_NLS
 # ifndef NLS_CAT_NAME
 #  define NLS_CAT_NAME   "whois"
@@ -61,25 +62,3 @@
 # endif
 #endif
 
-#ifdef HAVE_GETOPT_LONG
-# define GETOPT_LONGISH(c, v, o, l, i) getopt_long(c, v, o, l, i)
-#else
-# define GETOPT_LONGISH(c, v, o, l, i) getopt(c, v, o)
-#endif
-
-
-/* NLS stuff */
-#ifdef ENABLE_NLS
-# include <libintl.h>
-# include <locale.h>
-# define _(a) (gettext (a))
-# ifdef gettext_noop
-#  define N_(a) gettext_noop (a)
-# else
-#  define N_(a) (a)
-# endif
-#else
-# define _(a) (a)
-# define N_(a) a
-#endif
-
